@@ -3,6 +3,7 @@ from airflow.utils.decorators import apply_defaults
 from gcp_airflow_foundations.operators.api.hooks.mailgun_hook_test import MailgunHook
 from typing import Any
 
+
 class MailgunValidateSensor(BaseSensorOperator):
     @apply_defaults
     def __init__(self, mailgun_conn: str, job_id: str, **kwargs: Any):
@@ -12,4 +13,4 @@ class MailgunValidateSensor(BaseSensorOperator):
 
     def poke(self, context):
         res = self.hook.check_job_status(self.job_id)
-        return 'download_url' in res.json()
\ No newline at end of file
+        return "download_url" in res.json()
