@@ -5,7 +5,6 @@ from gcp_airflow_foundations.common.gcp.source_schema.bq import read_schema_from
 
 
 class SchemaSourceConfig(ABC):
-
     @abstractmethod
     def schema_method(self):
         pass
@@ -15,7 +14,6 @@ class SchemaSourceConfig(ABC):
         pass
 
 class AutoSchemaSourceConfig(SchemaSourceConfig):
-
     def schema_method(self):
         return
 
@@ -24,23 +22,24 @@ class AutoSchemaSourceConfig(SchemaSourceConfig):
 
 
 class GCSSchemaSourceConfig(SchemaSourceConfig):
-
     def schema_method(self):
         return read_schema_from_gcs
 
     def schema_method_arguments(self, data_source, table_config, ds):
         return {
-                'gcs_schema_object':data_source.schema_options.schema_object_template.format(table_name=table_config.table_name)
-            }
+            "gcs_schema_object": data_source.schema_options.schema_object_template.format(
+                table_name=table_config.table_name
+            )
+        }
 
 
 class BQLandingZoneSchemaSourceConfig(SchemaSourceConfig):
-
     def schema_method(self):
         return read_schema_from_bq
 
     def schema_method_arguments(self, data_source, table_config, ds):
         return {
-                'dataset_id':data_source.landing_zone_options.landing_zone_dataset, 
-                'table_id':f"{table_config.landing_zone_table_name_override}_{ds}"
-            }
+            "dataset_id": data_source.landing_zone_options.landing_zone_dataset,
+            "table_id": f"{table_config.landing_zone_table_name_override}_{ds}",
+            "project_id": data_source.gcp_project
+        }
